/*
 * Copyright (c) 2016, Uber Technologies, Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package com.uber.jaeger.httpclient;

import io.opentracing.propagation.TextMap;
import java.util.Iterator;
import java.util.Map;
import org.apache.http.HttpRequest;
import org.apache.http.message.BasicHeader;

/**
 * This is used propagate spans from the apache http client to servers that it is interacting with.
 * See also: {@link io.opentracing.Tracer#inject(SpanContext, Format, Object)}
 */
class ClientRequestCarrier implements TextMap {
  private final HttpRequest request;

  ClientRequestCarrier(HttpRequest request) {
    this.request = request;
  }

  @Override
  public Iterator<Map.Entry<String, String>> iterator() {
    throw new UnsupportedOperationException();
  }

  @Override
  public void put(String key, String value) {
    request.addHeader(new BasicHeader(key, value));
  }
}
